package com.tds.tapad.demo.banner;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.view.View;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.Toast;

import com.tapsdk.tapad.AdRequest;
import com.tapsdk.tapad.TapAdManager;
import com.tapsdk.tapad.TapAdNative;
import com.tapsdk.tapad.TapBannerAd;
import com.tapsdk.tapad.internal.utils.TapADLogger;
import com.tds.tapad.demo.R;
import com.tds.tapad.demo.utils.AdSpaceIdParser;
import com.tds.tapad.demo.views.BaseActivity;
import com.tds.tapad.demo.widget.TDSToastManager;

import java.util.HashMap;
import java.util.Map;

public class LandscapeBannerActivity extends BaseActivity {

    private TapAdNative tapAdNative;

    private Button fetchBannerAdButton;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN);
        setContentView(R.layout.activity_banner_landscape);
        setCustomActionBarTitleTextResource(R.string.sub_menu_horizontal_banner);
        tapAdNative = TapAdManager.get().createAdNative(this);
        fetchBannerAdButton = (Button) findViewById(R.id.fetchBannerAdButton);
        fetchBannerAdButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                final AdSpaceIdParser.BannerIds bannerIds = AdSpaceIdParser.getBannerIds();
                if (null == bannerIds) {
                    Toast.makeText(LandscapeBannerActivity.this, "Space id not configured", Toast.LENGTH_SHORT).show();
                    return;
                }
                int adId = bannerIds.horizontalId;
                TDSToastManager.instance().showLoading(LandscapeBannerActivity.this);
                tapAdNative.loadBannerAd(new AdRequest.Builder().withSpaceId(adId).withQuery("格斗")
                        .build(), new TapAdNative.BannerAdListener() {
                    @Override
                    public void onError(int code, String message) {
                        TDSToastManager.instance().dismiss();
                        Toast.makeText(LandscapeBannerActivity.this, "get banner error:(" + code + "," + message + ")", Toast.LENGTH_SHORT).show();
                    }

                    @Override
                    public void onBannerAdLoad(TapBannerAd bannerAd) {
                        TDSToastManager.instance().dismiss();
                        TapADLogger.d("landscape bannerAd bidPrice:" +  bannerAd.getMediaExtraInfo().get("bid_price")
                                + ", bidType:" + bannerAd.getMediaExtraInfo().get("bid_type"));
                        Toast.makeText(LandscapeBannerActivity.this, "get banner success", Toast.LENGTH_SHORT).show();
                        long biddingPrice = 0L;
                        if (bannerAd.getMediaExtraInfo() != null && bannerAd.getMediaExtraInfo().containsKey("bid_price")) {
                            biddingPrice = (Long) bannerAd.getMediaExtraInfo().get("bid_price");
                        }
                        Map<String, Object> map = new HashMap<>();
                        // todo to implement
//                        if (AdExperiment.get().getAttribute("report_bidding_state", Integer.class, 0) > 0) {
//                            map.put(Constants.Bidding.EXPECT_COST_PRICE, biddingPrice);
//                            map.put(Constants.Bidding.HIGHEST_LOSS_PRICE, 3000);
//                            bannerAd.sendWinNotification(map);
//                        } else {
//                            map.put(Constants.Bidding.WIN_PRICE, 1500);
//                            map.put(Constants.Bidding.LOSS_REASON, Constants.BiddingLossReason.LOW_PRICE);
//                            map.put(Constants.Bidding.ADN_ID, 2);
//                            bannerAd.sendLossNotification(map);
//                        }
                        bannerAd.setBannerInteractionListener(new TapBannerAd.BannerInteractionListener() {

                            @Override
                            public void onAdShow() {
                            }

                            @Override
                            public void onAdClose() {
                                Toast.makeText(LandscapeBannerActivity.this, "banner onAdClose", Toast.LENGTH_SHORT).show();
                            }

                            @Override
                            public void onAdClick() {
                                Toast.makeText(LandscapeBannerActivity.this, "banner onAdClick", Toast.LENGTH_SHORT).show();
                            }

                            @Override
                            public void onDownloadClick() {
                                Toast.makeText(LandscapeBannerActivity.this, "banner onDownloadClick", Toast.LENGTH_SHORT).show();
                            }
                        });

//                        ((LinearLayout)((FrameLayout)getWindow().getDecorView().findViewById(android.R.id.content)).findViewById(R.id.bannerContainer)).addView(bannerAd.getBannerView());
                        bannerAd.show(LandscapeBannerActivity.this, 1, 100);
                    }
                });
            }
        });
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        tapAdNative.dispose();
        TDSToastManager.instance().dismiss();
    }
}
