package com.tds.tapad.demo.interstitial;

import android.app.Activity;
import android.content.pm.ActivityInfo;
import android.content.res.Configuration;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Toast;

import com.tapsdk.tapad.AdRequest;
import com.tapsdk.tapad.TapAdManager;
import com.tapsdk.tapad.TapAdNative;
import com.tapsdk.tapad.TapInterstitialAd;
import com.tapsdk.tapad.internal.utils.TapADLogger;
import com.tds.tapad.demo.R;
import com.tds.tapad.demo.SimpleViewBinding;
import com.tds.tapad.demo.utils.AdSpaceIdParser;
import com.tds.tapad.demo.utils.ViewUtils;
import com.tds.tapad.demo.views.BaseActivity;
import com.tds.tapad.demo.widget.TDSToastManager;

public class InterstitialActivity extends BaseActivity implements SimpleViewBinding {
    private static final String TAG = "InterstitialActivity";
    private TapAdNative tapAdNative;
    private TapInterstitialAd latestInterstitialAd;

    private static long startTime;

    static {

    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_interstital);
        setCustomActionBarTitleTextResource(R.string.main_menu_interstitial);
        bindViews();
        tapAdNative = TapAdManager.get().createAdNative(this);
    }

    @Override
    public void bindViews() {

        final AdSpaceIdParser.InterstitialIds interstitialIds = AdSpaceIdParser.getInterstitialIds();
        if (null == interstitialIds) {
            Toast.makeText(this, "广告 id 配置异常",  Toast.LENGTH_SHORT).show();
            finish();
        }

        ViewUtils.bindView(this, R.id.change_landscape_portrait, new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                if (InterstitialActivity.this.getResources().getConfiguration().orientation != Configuration.ORIENTATION_LANDSCAPE) {
                    setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);
                } else {
                    setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_UNSPECIFIED);
                }
            }
        });

        ViewUtils.bindView(this, R.id.express_full_interaction_vertical_ad, new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                if (null == interstitialIds) return;
                int adId = interstitialIds.verticalInterstitialIds.fullScreenId;
                startTime = System.currentTimeMillis();
                loadAd(adId);
            }
        });

        ViewUtils.bindView(this, R.id.express_full_interaction_landscape_ad, new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                if (null == interstitialIds) return;
                int adId = interstitialIds.horizontalInterstitialIds.fullScreenId;
                startTime = System.currentTimeMillis();
                loadAd(adId);
            }
        });

        ViewUtils.bindView(this, R.id.express_half_interaction_landscape_ad, new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                if (null == interstitialIds) return;
                int adId = interstitialIds.horizontalInterstitialIds.halfScreenId;
                startTime = System.currentTimeMillis();
                loadAd(adId);
            }
        });

        ViewUtils.bindView(this, R.id.express_half_interaction_vertical_ad, new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                if (null == interstitialIds) return;
                int adId = interstitialIds.verticalInterstitialIds.halfScreenId;
                startTime = System.currentTimeMillis();
                loadAd(adId);
            }
        });

        ViewUtils.bindView(this, R.id.show_interaction_ad, new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                showAd(InterstitialActivity.this);
                // todo exp_count_down_close
                InterstitialActivity.this.latestInterstitialAd.setInteractionListener(new TapInterstitialAd.InterstitialAdInteractionListener() {
                    @Override
                    public void onAdShow() {

                    }

                    @Override
                    public void onAdClose() {
                        if (InterstitialActivity.this.latestInterstitialAd != null) {
                            InterstitialActivity.this.latestInterstitialAd.dispose();
                        }
                    }

                    @Override
                    public void onAdError() {

                    }
                });
            }
        });

        ViewUtils.bindView(this, R.id.count_down_close, new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                // todo to implement
                Toast.makeText(InterstitialActivity.this, "未实现", Toast.LENGTH_SHORT).show();
            }
        });

        ViewUtils.bindView(this, R.id.set_half_video_ad, new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Toast.makeText(InterstitialActivity.this, "未实现", Toast.LENGTH_SHORT).show();
            }
        });

        ViewUtils.bindView(this, R.id.set_half_video_hotzone, new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Toast.makeText(InterstitialActivity.this, "未实现", Toast.LENGTH_SHORT).show();
            }
        });
    }

    @Override
    protected void onResume() {
        super.onResume();
    }

    /**
     * 加载广告
     *
     * @param spaceId 对应 ssp 平台的广告位
     */
    private void loadAd(int spaceId) {
        TapADLogger.e("adId" + spaceId);
        TDSToastManager.instance().showLoading(this);
        AdRequest adRequest = new AdRequest.Builder()
                .withSpaceId(spaceId)
                .withQuery("热血")
                .build();
        tapAdNative.loadInterstitialAd(adRequest, new AdLoadListener());
    }

    /**
     * 显示广告
     *
     * @param activity
     */
    public void showAd(Activity activity) {
        if (latestInterstitialAd != null) {
            latestInterstitialAd.setInteractionListener(new AdInteractionListener());
            latestInterstitialAd.show(activity);
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        TDSToastManager.instance().dismiss();
    }

    private class AdLoadListener implements TapAdNative.InterstitialAdListener {
        @Override
        public void onInterstitialAdLoad(TapInterstitialAd ad) {
            Log.d(TAG,"广告加载完成");
            Toast.makeText(InterstitialActivity.this,"广告加载完成",Toast.LENGTH_SHORT).show();
            latestInterstitialAd = ad;
            TDSToastManager.instance().dismiss();
            Toast.makeText(getApplicationContext(), ("InterstitialAd bidPrice:" +  ad.getMediaExtraInfo().get("bid_price")
                    + ", bidType:" + ad.getMediaExtraInfo().get("bid_type")), Toast.LENGTH_SHORT).show();


            // todo implement report bidding result
//            long biddingPrice = 0L;
//            if (ad.getMediaExtraInfo() != null && ad.getMediaExtraInfo().containsKey("bid_price")) {
//                biddingPrice = (Long) ad.getMediaExtraInfo().get("bid_price");
//            }
//            Map<String, Object> map = new HashMap<>();
//            if (AdExperiment.get().getAttribute("report_bidding_state", Integer.class, 0) > 0) {
//                map.put(Constants.Bidding.EXPECT_COST_PRICE, biddingPrice);
//                map.put(Constants.Bidding.HIGHEST_LOSS_PRICE, 3000);
//                ad.sendWinNotification(map);
//            } else {
//                map.put(Constants.Bidding.WIN_PRICE, 1500);
//                map.put(Constants.Bidding.LOSS_REASON, Constants.BiddingLossReason.LOW_PRICE);
//                map.put(Constants.Bidding.ADN_ID, 2);
//                ad.sendLossNotification(map);
//            }

            showAd(InterstitialActivity.this);
        }

        @Override
        public void onError(int var1, String var2) {
            TDSToastManager.instance().dismiss();
            Log.d(TAG, "广告加载异常：" + var2);
            Toast.makeText(getApplicationContext(), var1 + "：" + var2, Toast.LENGTH_SHORT).show();
        }
    }

    private static class AdInteractionListener implements TapInterstitialAd.InterstitialAdInteractionListener {
        @Override
        public void onAdShow() {
            Log.d(TAG, "onShow");
            Log.d(TAG, (System.currentTimeMillis() - startTime) + "");
        }

        @Override
        public void onAdClose() {
            Log.d(TAG, "onAdClose");
        }

        @Override
        public void onAdError() {
            Log.d(TAG, "onAdError");
        }
    }
}
