package com.tds.tapad.demo.reward;

import android.content.res.Configuration;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.view.View;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.Toast;

import com.tapsdk.tapad.AdRequest;
import com.tapsdk.tapad.TapAdManager;
import com.tapsdk.tapad.TapAdNative;
import com.tapsdk.tapad.TapRewardVideoAd;
import com.tapsdk.tapad.constants.Constants;
import com.tapsdk.tapad.internal.utils.TapADLogger;
import com.tds.tapad.demo.R;
import com.tds.tapad.demo.utils.AdSpaceIdParser;
import com.tds.tapad.demo.views.BaseActivity;
import com.tds.tapad.demo.widget.TDSToastManager;

import java.util.HashMap;
import java.util.Map;

public class RewardHostActivity extends BaseActivity {

    private TapRewardVideoAd horizontalCachedAdInfo;

    private TapRewardVideoAd verticalCachedAdInfo;

    private TapAdNative tapAdNative;

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
    }

    @Override
    protected void onRestoreInstanceState(@NonNull Bundle savedInstanceState) {
        super.onRestoreInstanceState(savedInstanceState);
    }

    @Override
    protected void onSaveInstanceState(Bundle outState) {
        super.onSaveInstanceState(outState);
    }

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN);
        setContentView(R.layout.activity_reward);
        setCustomActionBarTitleTextResource(R.string.main_menu_reward);
        tapAdNative = TapAdManager.get().createAdNative(this);

        Button fetchHorizontalAdButton = (Button) findViewById(R.id.fetchHorizontalAdButton);
        fetchHorizontalAdButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                AdSpaceIdParser.RewardIds rewardIds = AdSpaceIdParser.getRewardIds();
                if (null == rewardIds) {
                    Toast.makeText(RewardHostActivity.this, "Space id not configured", Toast.LENGTH_SHORT).show();
                    return;
                }
                int adId = rewardIds.horizontalId;
                TDSToastManager.instance().showLoading(RewardHostActivity.this);
                AdRequest adRequest = new AdRequest.Builder()
                        .withSpaceId(adId)
                        .withExtra1("{}")
                        .withUserId("123")
                        .withRewordName("rewardName")
                        .withQuery("格斗")
                        .withRewordAmount(10)
                        .build();
                if (horizontalCachedAdInfo != null) {
                    horizontalCachedAdInfo.dispose();
                }

                tapAdNative.dispose();

                tapAdNative.loadRewardVideoAd(adRequest, new TapAdNative.RewardVideoAdListener() {
                    @Override
                    public void onError(int code, String message) {
                        TapADLogger.d("get ad fail(" + code + "/" + message + ")");
                        Toast.makeText(RewardHostActivity.this, "获取广告失败(" + code + "/" + message + ")", Toast.LENGTH_SHORT).show();
                        TDSToastManager.instance().dismiss();
                    }

                    @Override
                    public void onRewardVideoAdLoad(TapRewardVideoAd rewardVideoAd) {
                        TapADLogger.d("get ad success" + rewardVideoAd);
                        // 聚合平台使用
                        TapADLogger.d("landscape rewardAd bidPrice:" +  rewardVideoAd.getMediaExtraInfo().get("bid_price")
                                + ", bidType:" + rewardVideoAd.getMediaExtraInfo().get("bid_type"));
                        horizontalCachedAdInfo = rewardVideoAd;
                        Toast.makeText(RewardHostActivity.this, "获取广告成功: portrait rewardAd bidPrice:" +  rewardVideoAd.getMediaExtraInfo().get("bid_price")+
                                ", bidType" + rewardVideoAd.getMediaExtraInfo().get("bid_type"), Toast.LENGTH_SHORT).show();

                        TDSToastManager.instance().dismiss();
                    }

                    @Override
                    public void onRewardVideoCached(TapRewardVideoAd rewardVideoAd) {
                        horizontalCachedAdInfo = rewardVideoAd;
                        Toast.makeText(RewardHostActivity.this, "获取广告素材成功", Toast.LENGTH_SHORT).show();
                        TDSToastManager.instance().dismiss();
                        rewardVideoAd.showRewardVideoAd(RewardHostActivity.this);
                    }
                });
            }
        });

        Button showHorizontalAdButton = (Button) findViewById(R.id.showHorizontalAdButton);
        showHorizontalAdButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (horizontalCachedAdInfo != null) {
                    horizontalCachedAdInfo.setRewardAdInteractionListener(new TapRewardVideoAd.RewardAdInteractionListener() {
                        @Override
                        public void onAdShow() {
                            Toast.makeText(RewardHostActivity.this, "onAdShow", Toast.LENGTH_SHORT).show();
                        }

                        @Override
                        public void onAdClose() {
                            Toast.makeText(RewardHostActivity.this, "onAdClose", Toast.LENGTH_SHORT).show();
                            if (horizontalCachedAdInfo != null) horizontalCachedAdInfo.dispose();
                            if (verticalCachedAdInfo != null) verticalCachedAdInfo.dispose();
                        }

                        @Override
                        public void onVideoComplete() {
                            Toast.makeText(RewardHostActivity.this, "onVideoComplete", Toast.LENGTH_SHORT).show();
                        }

                        @Override
                        public void onVideoError() {

                        }

                        @Override
                        public void onRewardVerify(boolean rewardVerify, int rewardAmount, String rewardName, int code, String msg) {
                            Toast.makeText(RewardHostActivity.this, "获得奖励", Toast.LENGTH_SHORT).show();
                        }

                        @Override
                        public void onSkippedVideo() {
                            Toast.makeText(RewardHostActivity.this, "onSkippedVideo", Toast.LENGTH_SHORT).show();
                        }

                        @Override
                        public void onAdClick() {
                            Toast.makeText(RewardHostActivity.this, "onAdClick", Toast.LENGTH_SHORT).show();
                        }
                    });
                    horizontalCachedAdInfo.showRewardVideoAd(RewardHostActivity.this);

                } else {
                    Toast.makeText(RewardHostActivity.this, "请先获取横屏广告", Toast.LENGTH_SHORT).show();
                }
            }
        });

        Button fetchVerticalAdButton = (Button) findViewById(R.id.fetchVerticalAdButton);
        fetchVerticalAdButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                AdSpaceIdParser.RewardIds rewardIds = AdSpaceIdParser.getRewardIds();
                if (null == rewardIds) {
                    Toast.makeText(RewardHostActivity.this, "Space id not configured", Toast.LENGTH_SHORT).show();
                    return;
                }
                int adId = rewardIds.verticalId;
                TDSToastManager.instance().showLoading(RewardHostActivity.this);
                AdRequest adRequest = new AdRequest.Builder()
                        .withSpaceId(adId)
                        .withExtra1("{}")
                        .withUserId("123")
                        .withQuery("格斗")
                        .build();

                if (verticalCachedAdInfo != null) {
                    verticalCachedAdInfo.dispose();
                }
                tapAdNative.dispose();
                tapAdNative.loadRewardVideoAd(adRequest, new TapAdNative.RewardVideoAdListener() {
                    @Override
                    public void onError(int code, String message) {
                        TapADLogger.d("get ad fail(" + code + "/" + message + ")");
                        Toast.makeText(RewardHostActivity.this, "获取广告失败(" + code + "/" + message + ")", Toast.LENGTH_SHORT).show();
                        TDSToastManager.instance().dismiss();
                    }

                    @Override
                    public void onRewardVideoAdLoad(TapRewardVideoAd rewardVideoAd) {
                        verticalCachedAdInfo = rewardVideoAd;
                        // 聚合平台使用
                        TapADLogger.d("portrait rewardAd bidPrice:" +  rewardVideoAd.getMediaExtraInfo().get("bid_price")
                                + ", bidType:" + rewardVideoAd.getMediaExtraInfo().get("bid_type"));
                        Toast.makeText(RewardHostActivity.this, "获取广告成功: portrait rewardAd bidPrice:" +  rewardVideoAd.getMediaExtraInfo().get("bid_price")+
                                ", bidType" + rewardVideoAd.getMediaExtraInfo().get("bid_type"), Toast.LENGTH_SHORT).show();
                        TDSToastManager.instance().dismiss();
                    }

                    @Override
                    public void onRewardVideoCached(TapRewardVideoAd rewardVideoAd) {
                        Toast.makeText(RewardHostActivity.this, "获取广告素材成功", Toast.LENGTH_SHORT).show();
                        TDSToastManager.instance().dismiss();
                        rewardVideoAd.showRewardVideoAd(RewardHostActivity.this);
                    }
                });
            }
        });

        Button showVerticalAdButton = (Button) findViewById(R.id.showVerticalAdButton);
        showVerticalAdButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (verticalCachedAdInfo != null) {
                    verticalCachedAdInfo.showRewardVideoAd(RewardHostActivity.this);
                    verticalCachedAdInfo.setRewardAdInteractionListener(new TapRewardVideoAd.RewardAdInteractionListener() {
                        @Override
                        public void onAdShow() {
                            Toast.makeText(RewardHostActivity.this, "onAdShow", Toast.LENGTH_SHORT).show();
                        }

                        @Override
                        public void onAdClose() {
                            Toast.makeText(RewardHostActivity.this, "onAdClose", Toast.LENGTH_SHORT).show();
                            if (horizontalCachedAdInfo != null) horizontalCachedAdInfo.dispose();
                            if (verticalCachedAdInfo != null) verticalCachedAdInfo.dispose();
                        }

                        @Override
                        public void onVideoComplete() {
                            Toast.makeText(RewardHostActivity.this, "onVideoComplete", Toast.LENGTH_SHORT).show();
                        }

                        @Override
                        public void onVideoError() {

                        }

                        @Override
                        public void onRewardVerify(boolean rewardVerify, int rewardAmount, String rewardName, int code, String msg) {
                            Toast.makeText(RewardHostActivity.this, "获得奖励", Toast.LENGTH_SHORT).show();
                        }

                        @Override
                        public void onSkippedVideo() {
                            Toast.makeText(RewardHostActivity.this, "onSkippedVideo", Toast.LENGTH_SHORT).show();
                        }

                        @Override
                        public void onAdClick() {
                            Toast.makeText(RewardHostActivity.this, "onAdClick", Toast.LENGTH_SHORT).show();
                        }
                    });
                } else {
                    Toast.makeText(RewardHostActivity.this, "请先获竖屏取广告", Toast.LENGTH_SHORT).show();
                }
            }
        });

        Button reportBiddingLoseButton = (Button) findViewById(R.id.reportBiddingLoseButton);
        reportBiddingLoseButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                if (horizontalCachedAdInfo != null) {
                    Map<String, Object> map = new HashMap<>();
                    map.put(Constants.Bidding.WIN_PRICE, 1500);
                    map.put(Constants.Bidding.LOSS_REASON, Constants.BiddingLossReason.LOW_PRICE);
                    map.put(Constants.Bidding.ADN_ID, 2);
                    horizontalCachedAdInfo.sendLossNotification(map);
                } else if (verticalCachedAdInfo != null) {
                    Map<String, Object> map = new HashMap<>();
                    map.put(Constants.Bidding.WIN_PRICE, 1500);
                    map.put(Constants.Bidding.LOSS_REASON, Constants.BiddingLossReason.LOW_PRICE);
                    map.put(Constants.Bidding.ADN_ID, 2);
                    verticalCachedAdInfo.sendLossNotification(map);
                }
            }
        });
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        TDSToastManager.instance().dismiss();
        if (horizontalCachedAdInfo != null) {
            horizontalCachedAdInfo.setRewardAdInteractionListener(null);
            horizontalCachedAdInfo.dispose();
        }
        if (verticalCachedAdInfo != null) {
            verticalCachedAdInfo.setRewardAdInteractionListener(null);
            verticalCachedAdInfo.dispose();
        }
    }
}
