package com.tds.tapad.demo.splash;

import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.view.View;
import android.view.WindowManager;
import android.widget.Toast;

import com.tapsdk.tapad.AdRequest;
import com.tapsdk.tapad.TapAdManager;
import com.tapsdk.tapad.TapAdNative;
import com.tapsdk.tapad.TapSplashAd;
import com.tapsdk.tapad.internal.utils.TapADLogger;
import com.tds.tapad.demo.R;
import com.tds.tapad.demo.utils.AdSpaceIdParser;
import com.tds.tapad.demo.utils.DeviceUtils;
import com.tds.tapad.demo.utils.UIUtils;
import com.tds.tapad.demo.views.BaseActivity;
import com.tds.tapad.demo.widget.TDSToastManager;

public class SplashHostActivity extends BaseActivity {

    private TapAdNative tapAdNative;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN);
        setContentView(R.layout.activity_splash_host);
        setCustomActionBarTitleTextResource(R.string.main_menu_splash);
        tapAdNative = TapAdManager.get().createAdNative(this);

        findViewById(R.id.portraitSplashAdButton).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                int width = DeviceUtils.getScreenWidth(SplashHostActivity.this);
                int height = DeviceUtils.getScreenHeight(SplashHostActivity.this) - UIUtils.dp2px(SplashHostActivity.this, 80);
                AdSpaceIdParser.SplashIds splashIds = AdSpaceIdParser.getSplashIds();
                if (null == splashIds) {
                    Toast.makeText(SplashHostActivity.this, "Space id not configured", Toast.LENGTH_SHORT).show();
                    return;
                }
                int adId = splashIds.verticalId;
                TDSToastManager.instance().showLoading(SplashHostActivity.this);
                tapAdNative.loadSplashAd(new AdRequest.Builder().withSpaceId(adId)
                        .withExpressViewAcceptedSize(width, height)
                        .build(), new TapAdNative.SplashAdListener() {

                    @Override
                    public void onError(int code, String message) {
                        TDSToastManager.instance().dismiss();
                        Toast.makeText(SplashHostActivity.this, "获取竖屏开屏广告失败(开屏广告会)", Toast.LENGTH_SHORT).show();
                        TapADLogger.e("code:" + code + ",message:" + message);
                        SplashAdManager.getInstance().cachePortraitSplashAd(null);
                    }

                    @Override
                    public void onSplashAdLoad(TapSplashAd splashAd) {
                        long biddingPrice = 0L;
                        int bidType = -1;
                        try {
                            if (splashAd.getMediaExtraInfo() != null) {
                                if (splashAd.getMediaExtraInfo().containsKey("bid_price")) {
                                    biddingPrice = (Long) splashAd.getMediaExtraInfo().get("bid_price");
                                }
                                if (splashAd.getMediaExtraInfo().containsKey("bid_type")) {
                                    bidType = (int) splashAd.getMediaExtraInfo().get("bid_type");
                                }
                            }
                        } catch (Exception ignore) {

                        }
                        TDSToastManager.instance().dismiss();
                        TapADLogger.d("splashAd bidPrice:" +  biddingPrice
                                + ", bidType:" + bidType);
                        TapADLogger.d("获取竖屏开屏广告成功");
                        Toast.makeText(SplashHostActivity.this, "获取竖屏开屏广告成功. "+ "splashAd bidPrice:" +  splashAd.getMediaExtraInfo().get("bid_price")
                                + ", bidType:" + splashAd.getMediaExtraInfo().get("bid_type"), Toast.LENGTH_SHORT).show();
                        SplashAdManager.getInstance().cachePortraitSplashAd(splashAd);

                        Intent intent = new Intent(SplashHostActivity.this, PortraitSplashActivity.class);
                        startActivity(intent);
                    }
                });
            }
        });

        findViewById(R.id.landscapeSplashAdButton).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                AdSpaceIdParser.SplashIds splashIds = AdSpaceIdParser.getSplashIds();
                if (null == splashIds) {
                    Toast.makeText(SplashHostActivity.this, "Space id not configured", Toast.LENGTH_SHORT).show();
                    return;
                }
                int adId = splashIds.horizontalId;
                TDSToastManager.instance().showLoading(SplashHostActivity.this);
                tapAdNative.loadSplashAd(new AdRequest.Builder().withSpaceId(adId).build(), new TapAdNative.SplashAdListener() {

                    @Override
                    public void onError(int code, String message) {
                        TDSToastManager.instance().dismiss();
                        Toast.makeText(SplashHostActivity.this, "获取横开屏广告失败", Toast.LENGTH_SHORT).show();
                        TapADLogger.e("code:" + code + ",message:" + message);
                        SplashAdManager.getInstance().cacheLandscapeSplashAd(null);
                    }

                    @Override
                    public void onSplashAdLoad(TapSplashAd splashAd) {
                        TDSToastManager.instance().dismiss();
                        TapADLogger.d("获取横屏开屏广告成功");
                        Toast.makeText(SplashHostActivity.this, "获取横屏开屏广告成功: splashAd bidPrice:" +  splashAd.getMediaExtraInfo().get("bid_price")
                                + ", bidType:" + splashAd.getMediaExtraInfo().get("bid_type"), Toast.LENGTH_SHORT).show();
                        SplashAdManager.getInstance().cacheLandscapeSplashAd(splashAd);
                        Intent intent = new Intent(SplashHostActivity.this, LandscapeSplashActivity.class);
                        startActivity(intent);
                    }
                });
            }
        });
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        TDSToastManager.instance().dismiss();
        if (SplashAdManager.getInstance().getCachedPortraitSplashAd() != null) {
            SplashAdManager.getInstance().getCachedPortraitSplashAd().dispose();
            SplashAdManager.getInstance().getCachedPortraitSplashAd().destroyView();
            SplashAdManager.getInstance().cachePortraitSplashAd(null);
        }
        if (SplashAdManager.getInstance().getCachedLandscapeSplashAd() != null) {
            SplashAdManager.getInstance().getCachedLandscapeSplashAd().dispose();
            SplashAdManager.getInstance().getCachedLandscapeSplashAd().destroyView();
            SplashAdManager.getInstance().cacheLandscapeSplashAd(null);
        }
    }
}
