package com.tds.tapad.demo.utils;

import android.content.Context;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.annotations.SerializedName;
import com.google.gson.reflect.TypeToken;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class AdSpaceIdParser {

    private static final int DEFAULT_ID = -1;

    public static final String CHANNEL_TAP = "tap";

//    public static final String CHANNEL_TOBID = "tobid";
//
//    public static final String CHANNEL_TRADPLUS = "tradplus";

    private static final Map<String, AdChannel> adSpaceIdMap = new HashMap<>();

    private static String currentChannelName = CHANNEL_TAP;

    public static class FeedIds {

        @SerializedName(value = "video")
        public int videoId = DEFAULT_ID;

        @SerializedName(value = "picture")
        public int pictureId = DEFAULT_ID;
    }

    public static class HorizontalInterstitialIds {
        @SerializedName(value = "full")
        public int fullScreenId = DEFAULT_ID;

        @SerializedName(value = "half")
        public int halfScreenId = DEFAULT_ID;
    }

    public static class VerticalInterstitialIds {
        @SerializedName(value = "full")
        public int fullScreenId = DEFAULT_ID;

        @SerializedName(value = "half")
        public int halfScreenId = DEFAULT_ID;
    }

    public static class InterstitialIds {
        @SerializedName(value = "horizontal")
        public HorizontalInterstitialIds horizontalInterstitialIds;

        @SerializedName(value = "vertical")
        public VerticalInterstitialIds verticalInterstitialIds;
    }

    public static class BannerIds {
        @SerializedName("horizontal")
        public int horizontalId = DEFAULT_ID;

        @SerializedName("vertical")
        public int verticalId = DEFAULT_ID;
    }

    public static class SplashIds {
        @SerializedName("horizontal")
        public int horizontalId = DEFAULT_ID;

        @SerializedName("vertical")
        public int verticalId = DEFAULT_ID;
    }

    public static class RewardIds {
        @SerializedName("horizontal")
        public int horizontalId = DEFAULT_ID;

        @SerializedName("vertical")
        public int verticalId = DEFAULT_ID;
    }

    public static class AdChannel {

        @SerializedName(value = "channel_name")
        public final String channelName;

        @SerializedName(value = "feed")
        public final FeedIds feedIds;

        @SerializedName(value = "interstitial")
        public final InterstitialIds interstitialIds;

        @SerializedName(value = "banner")
        public final BannerIds bannerIds;

        @SerializedName(value = "splash")
        public final SplashIds splashIds;

        @SerializedName(value = "reward")
        public final RewardIds rewardIds;

        public AdChannel() {
            channelName = null;
            feedIds = null;
            interstitialIds = null;
            bannerIds = null;
            splashIds = null;
            rewardIds = null;
        }

        public AdChannel(String channelName
            , FeedIds feedIds
            , InterstitialIds interstitialIds
            , BannerIds bannerIds
            , SplashIds splashIds
            , RewardIds rewardIds
        ) {
            this.channelName = channelName;
            this.feedIds = feedIds;
            this.interstitialIds = interstitialIds;
            this.bannerIds = bannerIds;
            this.splashIds = splashIds;
            this.rewardIds = rewardIds;
        }
    }

    private static boolean initialized = false;

    public synchronized static void setup(Context context) {
        if (initialized) return;
        Gson gson = new GsonBuilder().setPrettyPrinting().create();
        String adsJsonStr = FileUtils.readFileFromAssets(context, "channel_space_ids.json");
        List<AdChannel> adChannelList = null;
        adChannelList = gson.fromJson(adsJsonStr, new TypeToken<List<AdChannel>>(){}.getType());

        for (int i = 0 ; i < adChannelList.size() ; i ++) {
            AdChannel adChannel = adChannelList.get(i);
            adSpaceIdMap.put(adChannel.channelName, adChannel);
        }
        initialized = true;
    }

    public static AdChannel getCurrentAdChannel() {
        if (!initialized) throw new IllegalStateException("AdSpaceIdParser should setup first");
        return adSpaceIdMap.get(currentChannelName);
    }


    public static String getChannelName() {
        return getCurrentAdChannel().channelName;
    }

    public static FeedIds getFeedIds() {
        return getCurrentAdChannel().feedIds;
    }

    public static InterstitialIds getInterstitialIds() {
        return getCurrentAdChannel().interstitialIds;
    }

    public static BannerIds getBannerIds() {
        return getCurrentAdChannel().bannerIds;
    }

    public static SplashIds getSplashIds() {
        return getCurrentAdChannel().splashIds;
    }

    public static RewardIds getRewardIds() {
        return getCurrentAdChannel().rewardIds;
    }
}
